@@ -121,7 +121,7 @@ Here's an example to illustrate some of these concepts:
 >        -- Also, we'd like to still ignore things less than
 >        -- WARNING in other areas.
 >        -- 
->        -- So, we adjust the Logger for MyApp.Component.
+>        -- So, we adjust the Logger for MyApp.BuggyComponent.
 >
 >        updateGlobalLogger "MyApp.BuggyComponent"
 >                           (setLevel DEBUG)
@@ -462,6 +462,7 @@ traplogging logger priority desc action =
     let realdesc = case desc of
                              "" -> ""
                              x -> x ++ ": "
+        handler :: Control.Exception.SomeException -> IO a
         handler e = do
                     logM logger priority (realdesc ++ (show e))
                     Control.Exception.throw e             -- Re-raise it
